Lock Methods — Rucio 0.3.8 documentation

# Lock Methods

Copyright European Organization for Nuclear Research (CERN) Licensed under the Apache License, Version 2.0 (the “License”); You may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0

Authors: - Martin Barisits, <martin.barisits@cern.ch>, 2014 - Ralph Vigne, <ralph.vigne@cern.ch>, 2015

class `rucio.client.lockclient.` `LockClient`(rucio_host=None, auth_host=None, account=None, ca_cert=None, auth_type=None, creds=None, timeout=None, user_agent='rucio-clients')

  Bases: `rucio.client.baseclient.BaseClient`

  Lock client class for working with rucio locks

  `LOCKS_BASEURL` = 'locks'
  `get_dataset_locks`(scope, name)

    Get a dataset locks of the specified dataset.

    Parameters: | scope – the scope of the did of the locks to list. name – the name of the did of the locks to list.

  `get_dataset_locks_by_rse`(rse)

    Get all dataset locks of the specified rse.

    Parameters: | rse – the rse of the locks to list.